@@ -25,10 +25,6 @@ from hbmqtt.adapters import (
     WebSocketsWriter)
 from .plugins.manager import PluginManager, BaseContext
 
-if sys.version_info < (3, 5):
-    from asyncio import async as ensure_future
-else:
-    from asyncio import ensure_future
 
 _defaults = {
     'timeout-disconnect-delay': 2,
@@ -250,7 +246,12 @@ class Broker:
 
                     if ssl_active:
                         try:
-                            sc = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+                            sc = ssl.create_default_context(
+                                ssl.Purpose.CLIENT_AUTH,
+                                cafile=listener.get('cafile'),
+                                capath=listener.get('capath'),
+                                cadata=listener.get('cadata')
+                            )
                             sc.load_cert_chain(listener['certfile'], listener['keyfile'])
                             sc.verify_mode = ssl.CERT_OPTIONAL
                         except KeyError as ke:
@@ -287,7 +288,7 @@ class Broker:
             yield from self.plugins_manager.fire_event(EVENT_BROKER_POST_START)
 
             #Start broadcast loop
-            self._broadcast_task = ensure_future(self._broadcast_loop(), loop=self._loop)
+            self._broadcast_task = asyncio.ensure_future(self._broadcast_loop(), loop=self._loop)
 
             self.logger.debug("Broker started")
         except Exception as e:
@@ -370,7 +371,7 @@ class Broker:
 
         if client_session.clean_session:
             # Delete existing session and create a new one
-            if client_session.client_id is not None:
+            if client_session.client_id is not None and client_session.client_id != "":
                 self.delete_session(client_session.client_id)
             else:
                 client_session.client_id = gen_client_id()
@@ -393,6 +394,7 @@ class Broker:
         authenticated = yield from self.authenticate(client_session, self.listeners_config[listener_name])
         if not authenticated:
             yield from writer.close()
+            server.release_connection()  # Delete client from connections list
             return
 
         while True:
@@ -414,10 +416,10 @@ class Broker:
         yield from self.publish_session_retained_messages(client_session)
 
         # Init and start loop for handling client messages (publish, subscribe/unsubscribe, disconnect)
-        disconnect_waiter = ensure_future(handler.wait_disconnect(), loop=self._loop)
-        subscribe_waiter = ensure_future(handler.get_next_pending_subscription(), loop=self._loop)
-        unsubscribe_waiter = ensure_future(handler.get_next_pending_unsubscription(), loop=self._loop)
-        wait_deliver = ensure_future(handler.mqtt_deliver_next_message(), loop=self._loop)
+        disconnect_waiter = asyncio.ensure_future(handler.wait_disconnect(), loop=self._loop)
+        subscribe_waiter = asyncio.ensure_future(handler.get_next_pending_subscription(), loop=self._loop)
+        unsubscribe_waiter = asyncio.ensure_future(handler.get_next_pending_unsubscription(), loop=self._loop)
+        wait_deliver = asyncio.ensure_future(handler.mqtt_deliver_next_message(), loop=self._loop)
         connected = True
         while connected:
             try:
@@ -464,7 +466,8 @@ class Broker:
                     subscriptions = subscribe_waiter.result()
                     return_codes = []
                     for subscription in subscriptions['topics']:
-                        return_codes.append(self.add_subscription(subscription, client_session))
+                        result = yield from self.add_subscription(subscription, client_session)
+                        return_codes.append(result)
                     yield from handler.mqtt_acknowledge_subscription(subscriptions['packet_id'], return_codes)
                     for index, subscription in enumerate(subscriptions['topics']):
                         if return_codes[index] != 0x80:
@@ -558,6 +561,41 @@ class Broker:
         # If all plugins returned True, authentication is success
         return auth_result
 
+    @asyncio.coroutine
+    def topic_filtering(self, session: Session, topic):
+        """
+        This method call the topic_filtering method on registered plugins to check that the subscription is allowed.
+        User is considered allowed if all plugins called return True.
+        Plugins topic_filtering() method are supposed to return :
+         - True if MQTT client can be subscribed to the topic
+         - False if MQTT client is not allowed to subscribe to the topic
+         - None if topic filtering can't be achieved (then plugin result is then ignored)
+        :param session:
+        :param listener:
+        :param topic: Topic in which the client wants to subscribe
+        :return:
+        """
+        topic_plugins = None
+        topic_config = self.config.get('topic-check', None)
+        if topic_config and topic_config.get('enabled', False):
+            topic_plugins = topic_config.get('plugins', None)
+        returns = yield from self.plugins_manager.map_plugin_coro(
+            "topic_filtering",
+            session=session,
+            topic=topic,
+            filter_plugins=topic_plugins)
+        topic_result = True
+        if returns:
+            for plugin in returns:
+                res = returns[plugin]
+                if res is False:
+                    topic_result = False
+                    self.logger.debug("Topic filtering failed due to '%s' plugin result: %s" % (plugin.name, res))
+                else:
+                    self.logger.debug("'%s' plugin result: %s" % (plugin.name, res))
+        # If all plugins returned True, authentication is success
+        return topic_result
+
     def retain_message(self, source_session, topic_name, data, qos=None):
         if data is not None and data != b'':
             # If retained flag set, store the message for further subscriptions
@@ -570,6 +608,7 @@ class Broker:
                 self.logger.debug("Clear retained messages for topic '%s'" % topic_name)
                 del self._retained_messages[topic_name]
 
+    @asyncio.coroutine
     def add_subscription(self, subscription, session):
         try:
             a_filter = subscription[0]
@@ -581,7 +620,10 @@ class Broker:
                     if "/+" not in a_filter and "+/" not in a_filter:
                         # [MQTT-4.7.1-3] + wildcard character must occupy entire level
                         return 0x80
-
+            # Check if the client is authorised to connect to the topic
+            permitted = yield from self.topic_filtering(session, topic=a_filter)
+            if not permitted:
+                return 0x80
             qos = subscription[1]
             if 'max-qos' in self.config and qos > self.config['max-qos']:
                 qos = self.config['max-qos']
@@ -666,7 +708,7 @@ class Broker:
                                                   (format_client_message(session=broadcast['session']),
                                                    broadcast['topic'], format_client_message(session=target_session)))
                                 handler = self._get_handler(target_session)
-                                task = ensure_future(
+                                task = asyncio.ensure_future(
                                     handler.mqtt_publish(broadcast['topic'], broadcast['data'], qos, retain=False),
                                     loop=self._loop)
                                 running_tasks.append(task)
@@ -702,7 +744,7 @@ class Broker:
         handler = self._get_handler(session)
         while not session.retained_messages.empty():
             retained = yield from session.retained_messages.get()
-            publish_tasks.append(ensure_future(
+            publish_tasks.append(asyncio.ensure_future(
                 handler.mqtt_publish(
                     retained.topic, retained.data, retained.qos, True), loop=self._loop))
         if publish_tasks:
