@@ -1,9 +1,14 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import logging
+
 import yaml
 
 
+logger = logging.getLogger(__name__)
+
+
 def not_in_dict_or_none(dict, key):
     """
     Check if a key exists in a map and if it's not None
@@ -38,6 +43,7 @@ def gen_client_id():
         gen_id += chr(random.randint(0, 74) + 48)
     return gen_id
 
+
 def read_yaml_config(config_file):
     config = None
     try:
@@ -45,4 +51,4 @@ def read_yaml_config(config_file):
             config = yaml.load(stream)
     except yaml.YAMLError as exc:
         logger.error("Invalid config_file %s: %s" % (config_file, exc))
-    return config
\ No newline at end of file
+    return config
