@@ -9,7 +9,7 @@ from hbmqtt.plugins.manager import PluginManager
 from hbmqtt.session import Session, OutgoingApplicationMessage, IncomingApplicationMessage
 from hbmqtt.mqtt.protocol.handler import ProtocolHandler
 from hbmqtt.adapters import StreamWriterAdapter, StreamReaderAdapter
-from hbmqtt.mqtt.constants import *
+from hbmqtt.mqtt.constants import QOS_0, QOS_1, QOS_2
 from hbmqtt.mqtt.publish import PublishPacket
 from hbmqtt.mqtt.puback import PubackPacket
 from hbmqtt.mqtt.pubrec import PubrecPacket
@@ -39,7 +39,7 @@ class ProtocolHandlerTest(unittest.TestCase):
         self.loop.close()
 
     def test_init_handler(self):
-        s = Session()
+        Session()
         handler = ProtocolHandler(self.plugin_manager, loop=self.loop)
         self.assertIsNone(handler.session)
         self.assertIs(handler._loop, self.loop)
@@ -78,8 +78,8 @@ class ProtocolHandlerTest(unittest.TestCase):
         def server_mock(reader, writer):
             try:
                 packet = yield from PublishPacket.from_stream(reader)
-                self.assertEquals(packet.variable_header.topic_name, '/topic')
-                self.assertEquals(packet.qos, QOS_0)
+                self.assertEqual(packet.variable_header.topic_name, '/topic')
+                self.assertEqual(packet.qos, QOS_0)
                 self.assertIsNone(packet.packet_id)
             except Exception as ae:
                 future.set_exception(ae)
@@ -119,8 +119,8 @@ class ProtocolHandlerTest(unittest.TestCase):
         def server_mock(reader, writer):
             packet = yield from PublishPacket.from_stream(reader)
             try:
-                self.assertEquals(packet.variable_header.topic_name, '/topic')
-                self.assertEquals(packet.qos, QOS_1)
+                self.assertEqual(packet.variable_header.topic_name, '/topic')
+                self.assertEqual(packet.qos, QOS_1)
                 self.assertIsNotNone(packet.packet_id)
                 self.assertIn(packet.packet_id, self.session.inflight_out)
                 self.assertIn(packet.packet_id, self.handler._puback_waiters)
@@ -166,15 +166,15 @@ class ProtocolHandlerTest(unittest.TestCase):
         def server_mock(reader, writer):
             try:
                 packet = yield from PublishPacket.from_stream(reader)
-                self.assertEquals(packet.topic_name, '/topic')
-                self.assertEquals(packet.qos, QOS_2)
+                self.assertEqual(packet.topic_name, '/topic')
+                self.assertEqual(packet.qos, QOS_2)
                 self.assertIsNotNone(packet.packet_id)
                 self.assertIn(packet.packet_id, self.session.inflight_out)
                 self.assertIn(packet.packet_id, self.handler._pubrec_waiters)
                 pubrec = PubrecPacket.build(packet.packet_id)
                 yield from pubrec.to_stream(writer)
 
-                pubrel = yield from PubrelPacket.from_stream(reader)
+                yield from PubrelPacket.from_stream(reader)
                 self.assertIn(packet.packet_id, self.handler._pubcomp_waiters)
                 pubcomp = PubcompPacket.build(packet.packet_id)
                 yield from pubcomp.to_stream(writer)
@@ -373,8 +373,8 @@ class ProtocolHandlerTest(unittest.TestCase):
         def server_mock(reader, writer):
             packet = yield from PublishPacket.from_stream(reader)
             try:
-                self.assertEquals(packet.topic_name, '/topic')
-                self.assertEquals(packet.qos, QOS_1)
+                self.assertEqual(packet.topic_name, '/topic')
+                self.assertEqual(packet.qos, QOS_1)
                 self.assertIsNotNone(packet.packet_id)
                 self.assertIn(packet.packet_id, self.session.inflight_out)
                 self.assertIn(packet.packet_id, self.handler._puback_waiters)
@@ -416,15 +416,15 @@ class ProtocolHandlerTest(unittest.TestCase):
         def server_mock(reader, writer):
             try:
                 packet = yield from PublishPacket.from_stream(reader)
-                self.assertEquals(packet.topic_name, '/topic')
-                self.assertEquals(packet.qos, QOS_2)
+                self.assertEqual(packet.topic_name, '/topic')
+                self.assertEqual(packet.qos, QOS_2)
                 self.assertIsNotNone(packet.packet_id)
                 self.assertIn(packet.packet_id, self.session.inflight_out)
                 self.assertIn(packet.packet_id, self.handler._pubrec_waiters)
                 pubrec = PubrecPacket.build(packet.packet_id)
                 yield from pubrec.to_stream(writer)
 
-                pubrel = yield from PubrelPacket.from_stream(reader)
+                yield from PubrelPacket.from_stream(reader)
                 self.assertIn(packet.packet_id, self.handler._pubcomp_waiters)
                 pubcomp = PubcompPacket.build(packet.packet_id)
                 yield from pubcomp.to_stream(writer)
