@@ -1,11 +1,11 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import asyncio
 import unittest
 
 from hbmqtt.mqtt.pubrec import PubrecPacket, PacketIdVariableHeader
 from hbmqtt.adapters import BufferReader
-from hbmqtt.codecs import *
 
 
 class PubrecPacketTest(unittest.TestCase):
@@ -22,4 +22,4 @@ class PubrecPacketTest(unittest.TestCase):
         variable_header = PacketIdVariableHeader(10)
         publish = PubrecPacket(variable_header=variable_header)
         out = publish.to_bytes()
-        self.assertEqual(out, b'\x50\x02\x00\x0a')
\ No newline at end of file
+        self.assertEqual(out, b'\x50\x02\x00\x0a')
